<?php
/**
 * @copyright 2021 Double Bastion LLC <www.doublebastion.com>
 *
 * @author Double Bastion LLC
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU AFFERO GENERAL PUBLIC LICENSE
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU AFFERO GENERAL PUBLIC LICENSE for more details.
 *
 * You should have received a copy of the GNU Affero General Public
 * License along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

declare(strict_types=1);

namespace OCA\PaxFax\Settings;

use OCP\IL10N;
use OCP\IURLGenerator;
use OCP\Settings\IIconSection;


class PersonalSection implements IIconSection {
        /** @var IL10N */
        private $l;
        /** @var IURLGenerator */
        private $url;

        /**
         * @param IURLGenerator $url
         * @param IL10N $l
         */
        public function __construct(IURLGenerator $url, IL10N $l) {
                $this->url = $url;
                $this->l = $l;
        }

        /**
         * returns the ID of the section. It is supposed to be a lower case string,
         * e.g. 'ldap'
         *
         * @returns string
         */
        public function getID() {
                return 'pax_fax';
        }

        /**
         * returns the translated name as it should be displayed, e.g. 'LDAP / AD
         * integration'. Use the L10N service to translate it.
         *
         * @return string
         */
        public function getName() {
                return $this->l->t('Pax Fax');
        }

        /**
         * @return int whether the form should be rather on the top or bottom of
         * the settings navigation. The sections are arranged in ascending order of
         * the priority values. It is required to return a value between 0 and 99.
         *
         * E.g.: 70
         */
        public function getPriority() {
                return 12;
        }

        /**
         * {@inheritdoc}
         */
        public function getIcon() {
                return $this->url->imagePath('pax_fax', 'pax_fax_dark.svg');
        }
}

