OC.L10N.register(
    "pax_fax",
    {
    "Settings" : "Settings",
    "Pax Fax" : "Pax Fax",
    "Please enter your credentials and options in the fields from below:" : "Please enter your credentials and options in the fields from below:",
    "Phaxio API Key:" : "Phaxio API Key:",
    "e.g. d6f172ce92e4f2 ..." : "e.g. d6f172ce92e4f2 ...",
    "Phaxio API Secret:" : "Phaxio API Secret:",
    "e.g. 8af589b8ad9579 ..." : "e.g. 8af589b8ad9579 ...",
    "Phaxio Webhook Token:" : "Phaxio Webhook Token:",
    "e.g. b6d90b72ab6cce450025abd46f4d697" : "e.g. b6d90b72ab6cce450025abd46f4d697",
    "e.g.  https://username:6VTGs-c36j4-qK2wm-RgJcl-9pjUD@cloud.example.com/apps/pax_fax/api/recfaxphaxio" : "e.g.  https://username:6VTGs-c36j4-qK2wm-RgJcl-9pjUD@cloud.example.com/apps/pax_fax/api/recfaxphaxio",
    "I want to see a notification in Nextcloud when a new fax is received:" : "I want to see a notification in Nextcloud when a new fax is received:",
    "I want to receive a notification to the email address from below, when a new fax is received:" : "I want to receive a notification to the email address from below, when a new fax is received:",
    "e.g. john.doe@example.com" : "e.g. john.doe@example.com",
    "Save" : "Save"
},
"nplurals=2; plural=(n != 1);");

